Produce tree with node labels in MCMCtree format
Usage
nodeToPhy(phy, monoGroups, nodeCon, returnPhy = TRUE)
Arguments
- phy
fully resolved phylogeny in ape format
- monoGroups
list with each element containing species that define a node of interest
- nodeCon
node distributions in MCMCtreeR format
- returnPhy
logical specifying whether to return phy to console or write MCMCtree for input (default = TRUE)
Value
If returnPhy=TRUE phylogeny with node labels in ape format
If returnPhy=FALSE phylogeny with node labels in MCMCtree format